@@ -58,7 +58,7 @@ read_fmi_cum <- function(file,
   
   if (!grepl("(J/m2/nm)", file_header[.skip], fixed = TRUE)) {
     warning("Skipping file with unrecognized format!")
-    return(source_spct())
+    return(photobiology::source_spct())
   }
   
   if (is.null(tz)) {
@@ -68,7 +68,8 @@ read_fmi_cum <- function(file,
 #  file_date <- file.mtime(file, tz = tz)[1]
   
   if (is.null(date)) {
-    date.char <- scan(text = file_header[2], nlines = 1, what = "z")[2]
+    date.char <- scan(text = file_header[2], nlines = 1, 
+                      what = "z", quiet = TRUE)[2]
     date.time <- .date.f(date.char, tz = tz) # tz needed as otherwise a "Date" is returned
   }
   
@@ -279,7 +280,7 @@ read_fmi2mspct <- function(file,
       length(header.start.idxs) != length(data.start.idxs) ||
       length(header.start.idxs) != length(data.end.idxs)) {
     warning("Unmatched delimiters or no delimiters found!")
-    return(source_mspct())
+    return(photobiology::source_mspct())
   }
   
   zz <- list()
